Markdown is a lightweight markup language used for formatting text. It is commonly used for formatting text on websites, in documentation, and in notes. Markdown is easy to learn and use, and it allows you to quickly and easily create well-formatted documents without the need for complex HTML or formatting tools.

In order to use markdown, you will need an editor that supports it. In our case, this is [VS code](https://code.visualstudio.com/), the editor we will also be using for writing and editing code. You are welcome to explore and use other editors for markdown (and we recommend this for note taking!). Remember that markdown is just a syntax for writing plain text files, so you can edit these files with multiple different editors. Some will render the syntax in place, others will require changing between editing and reading 'views'.

Here is an overview of the basic Markdown syntax with examples:

1. Headings:
   - Use one to six hash symbols (`#`) to create headings of different levels. The number of hash symbols represents the level of the heading.
   - Example: 

```bash
     # Heading 1
     ## Heading 2
     ### Heading 3
     
```

2. Paragraphs and line breaks:
   - Use a blank line to separate paragraphs.
   - Use two or more spaces at the end of a line to create a line break.
   - Example:

```csharp
     This is a paragraph.

     This is another paragraph with  
     a line break.
     
```

3. Emphasis and bold:
   - Use asterisks (`*`) or underscores (`_`) to emphasize text.
   - Use double asterisks (`**`) or double underscores (`__`) to make text bold.
   - Example:

```scss
     *Italic text*
     _Italic text_

     **Bold text**
     __Bold text__
     
```

4. Lists:
   - Use hyphens (`-`), plus symbols (`+`), or asterisks (`*`) to create unordered lists.
   - Use numbers followed by periods to create ordered lists.
   - Example:
```markdown
     - Item 1
     - Item 2
     - Item 3

     1. Item 1
     2. Item 2
     3. Item 3
     
```

5. Links:
   - Use square brackets (`[]`) to create a link text, followed by parentheses (`()`) with the URL or file path.
   - Example:

```less
     [Google](https://www.google.com)
     
```

6. Images:
   - Use an exclamation mark (`!`), followed by square brackets (`[]`) with the alt text, and parentheses (`()`) with the image URL or file path.
   - Example:

```less
     ![Alt text](https://example.com/image.jpg)
     
```

7. Code:
   - Use backticks (\`) to format inline code.
   - Use triple backticks (\`\`\`) to create code blocks.
   - Example:
     

```css
     `code`     
```

python
     def hello():
         print("Hello, World!")
     

These are just the basics of Markdown. There are many more features and extensions available, such as tables, blockquotes, and horizontal rules. Markdown is widely supported and can be used in various applications and platforms, including text editors, online platforms, and blogging platforms.

## Why use Markdown

Markdown is a lightweight markup language that offers numerous benefits for formatting text. Here are some of the key benefits to using markdown.

1. Simplicity: One of the primary benefits of Markdown is its simplicity. The syntax is straightforward and easy to learn, making it accessible to both technical and non-technical users. Unlike HTML or other complex formatting languages, Markdown uses plain text and simple characters to create structured documents.

2. Readability: Markdown focuses on the content rather than the formatting, resulting in clean and readable text. The use of simple symbols for formatting allows the writer to concentrate on the message without getting distracted by complex styling options. This makes Markdown ideal for creating documents such as blog posts, documentation, and notes.

3. Portability: Markdown files are plain text files, which means they can be opened and edited with any text editor. This portability makes Markdown a versatile choice for creating and sharing documents across different platforms and devices. Additionally, Markdown files can easily be converted to other formats like HTML, PDF, or Word, allowing for seamless integration with existing workflows.

4. Platform independence: Markdown is platform-independent, meaning it can be used on any operating system or device. Whether you're using Windows, macOS, Linux, or even a mobile device, Markdown is universally compatible. This flexibility makes it an excellent choice for collaborative projects and ensures that the formatting remains consistent across different platforms.

5. Version control: Markdown files are plain text, making them ideal for version control systems like Git. These systems track changes made to a document over time, allowing multiple contributors to collaborate on a project efficiently. With Markdown, changes are easily visible, and conflicts can be resolved more effectively, enhancing the overall collaboration experience.

6. Speed and efficiency: Markdown's lightweight syntax allows for quick and efficient writing. The use of simple characters for formatting eliminates the need for extensive mouse-clicking or navigating through complex menus. This speed and efficiency make Markdown an attractive option for writers who want to focus on their content without distraction.

7. Flexibility: Markdown offers a wide range of formatting options to suit different needs. Whether you need headings, lists, tables, code blocks, or even mathematical formulas, Markdown has you covered. Additionally, Markdown supports the use of HTML tags, providing even more flexibility for advanced formatting requirements.

8. Integration: Markdown can be seamlessly integrated into various platforms and applications. Many popular content management systems, blogging platforms, and note-taking apps support Markdown, allowing you to write and publish content directly from your preferred tools. Markdown can also be used in email clients, chat applications, and wikis, ensuring consistency across different communication channels.

9. Accessibility: Markdown is accessible to users with disabilities. Since it focuses on the content rather than visual presentation, screen readers and other assistive technologies can interpret and present Markdown files more effectively. This accessibility ensures that the content is available to a wider audience, regardless of their abilities.

10. Community and support: Markdown has a vast and active community of users who contribute to its development and provide support to fellow users. This community-driven nature means that there are countless resources available, including tutorials, guides, and plugins, to enhance your Markdown experience. Whether you need assistance or want to share your knowledge, the Markdown community is there to help.
